@@ -1,12 +1,12 @@
 /* Arabic joining type of Unicode characters.
-   Copyright (C) 2011-2022 Free Software Foundation, Inc.
+   Copyright (C) 2011-2026 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2011.
 
    This file is free software.
    It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
    You can redistribute it and/or modify it under either
      - the terms of the GNU Lesser General Public License as published
-       by the Free Software Foundation; either version 3, or (at your
+       by the Free Software Foundation, either version 3, or (at your
        option) any later version, or
      - the terms of the GNU General Public License as published by the
        Free Software Foundation; either version 2, or (at your option)
@@ -35,13 +35,10 @@
 int
 uc_joining_type_byname (const char *joining_type_name)
 {
-  size_t len;
-
-  len = strlen (joining_type_name);
+  size_t len = strlen (joining_type_name);
   if (len <= MAX_WORD_LENGTH)
     {
       char buf[MAX_WORD_LENGTH + 1];
-      const struct named_joining_type *found;
 
       /* Copy joining_type_name into buf, converting '_' and '-' to ' '.  */
       {
@@ -62,7 +59,8 @@ uc_joining_type_byname (const char *joining_type_name)
       /* Here q == buf + len.  */
 
       /* Do a hash table lookup, with case-insensitive comparison.  */
-      found = uc_joining_type_lookup (buf, len);
+      const struct named_joining_type *found =
+        uc_joining_type_lookup (buf, len);
       if (found != NULL)
         return found->joining_type;
     }
