@@ -1,6 +1,5 @@
 /* Next grapheme cluster function.
-   Copyright (C) 2010-2022 Free Software Foundation, Inc.
-   Written by Ben Pfaff <blp@cs.stanford.edu>, 2010.
+   Copyright (C) 2010-2026 Free Software Foundation, Inc.
 
    This file is free software.
    It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
@@ -23,32 +22,20 @@
    License and of the GNU General Public License along with this
    program.  If not, see <https://www.gnu.org/licenses/>.  */
 
+/* Written by Bruno Haible <bruno@clisp.org>, 2025.  */
+
+/* Don't use the const-improved function macros in this compilation unit.  */
+#define _LIBUNISTRING_NO_CONST_GENERICS
+
 #include <config.h>
 
 /* Specification.  */
 #include "unigbrk.h"
 
+#include "unictype.h"
 #include "unistr.h"
 
-const uint16_t *
-u16_grapheme_next (const uint16_t *s, const uint16_t *end)
-{
-  ucs4_t prev;
-  int mblen;
-
-  if (s == end)
-    return NULL;
-
-  for (s += u16_mbtouc (&prev, s, end - s); s != end; s += mblen)
-    {
-      ucs4_t next;
-
-      mblen = u16_mbtouc (&next, s, end - s);
-      if (uc_is_grapheme_break (prev, next))
-        break;
-
-      prev = next;
-    }
-
-  return s;
-}
+#define FUNC u16_grapheme_next
+#define UNIT uint16_t
+#define U_MBTOUC u16_mbtouc
+#include "u-grapheme-next.h"
