@@ -1,5 +1,5 @@
 /* Compare UTF-32 strings.
-   Copyright (C) 1999, 2002, 2006, 2009-2025 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2002, 2006, 2009-2026 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2002.
 
    This file is free software.
@@ -31,18 +31,16 @@
 int
 u32_strncmp (const uint32_t *s1, const uint32_t *s2, size_t n)
 {
-  for (; n > 0;)
+  for (; n > 0; n--)
     {
       uint32_t uc1 = *s1++;
       uint32_t uc2 = *s2++;
-      if (uc1 != 0 && uc1 == uc2)
+      if (uc1 == 0 || uc1 != uc2)
         {
-          n--;
-          continue;
+          /* Note that uc1 and uc2 each have at most 31 bits. */
+          return (int)uc1 - (int)uc2;
+          /* > 0 if uc1 > uc2, < 0 if uc1 < uc2, = 0 if uc1 and uc2 are both 0.  */
         }
-      /* Note that uc1 and uc2 each have at most 31 bits. */
-      return (int)uc1 - (int)uc2;
-      /* > 0 if uc1 > uc2, < 0 if uc1 < uc2, = 0 if uc1 and uc2 are both 0.  */
     }
   return 0;
 }
