@@ -1,9 +1,9 @@
 /* Test the Unicode character type functions.
-   Copyright (C) 2007-2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2026 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -12,7 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 
@@ -25,9 +25,9 @@
 int
 main ()
 {
-  ASSERT (uc_bidi_category ('x') == UC_BIDI_L);
-  ASSERT (uc_bidi_category (0x05D7) == UC_BIDI_R);
-  ASSERT (uc_bidi_category ('7') == UC_BIDI_EN);
+  ASSERT (uc_bidi_class ('x') == UC_BIDI_L);
+  ASSERT (uc_bidi_class (0x05D7) == UC_BIDI_R);
+  ASSERT (uc_bidi_class ('7') == UC_BIDI_EN);
 
-  return 0;
+  return test_exit_status;
 }
