@@ -1,9 +1,9 @@
 /* Test of uN_strstr() functions.
-   Copyright (C) 2004, 2007-2022 Free Software Foundation, Inc.
+   Copyright (C) 2004, 2007-2026 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -130,10 +130,8 @@ test_u_strstr (void)
     UNIT *haystack = (UNIT *) malloc ((m + 1) * sizeof (UNIT));
     if (haystack != NULL)
       {
-        size_t i;
-
         haystack[0] = 'B';
-        for (i = 1; i < m; i++)
+        for (size_t i = 1; i < m; i++)
           haystack[i] = 'A';
         haystack[m] = '\0';
 
@@ -166,9 +164,7 @@ test_u_strstr (void)
     UNIT *needle = (UNIT *) malloc ((m + 1) * sizeof (UNIT));
     if (needle != NULL)
       {
-        size_t i;
-
-        for (i = 0; i < m; i++)
+        for (size_t i = 0; i < m; i++)
           needle[i] = 'A';
         needle[m] = '\0';
 
@@ -188,15 +184,14 @@ test_u_strstr (void)
     UNIT *needle = (UNIT *) malloc ((m + 2) * sizeof (UNIT));
     if (haystack != NULL && needle != NULL)
       {
-        size_t i;
         const UNIT *result;
 
-        for (i = 0; i < 2 * m; i++)
+        for (size_t i = 0; i < 2 * m; i++)
           haystack[i] = 'A';
         haystack[2 * m] = 'B';
         haystack[2 * m + 1] = 0;
 
-        for (i = 0; i < m; i++)
+        for (size_t i = 0; i < m; i++)
           needle[i] = 'A';
         needle[m] = 'B';
         needle[m + 1] = 0;
@@ -207,4 +202,42 @@ test_u_strstr (void)
     free (needle);
     free (haystack);
   }
+
+  /* Test case from Yves Bastide.
+     <https://www.openwall.com/lists/musl/2014/04/18/2>  */
+  {
+    const UNIT input[] =
+      { 'p', 'l', 'a', 'y', 'i', 'n', 'g', ' ', 'p', 'l', 'a', 'y', ' ', 'p',
+        'l', 'a', 'y', ' ', 'p', 'l', 'a', 'y', ' ', 'a', 'l', 'w', 'a', 'y',
+        's', 0
+      };
+    const UNIT needle[] =
+      { 'p', 'l', 'a', 'y', ' ', 'p', 'l', 'a', 'y', ' ', 'p', 'l', 'a', 'y',
+        0
+      };
+    const UNIT *result = U_STRSTR (input, needle);
+    ASSERT (result == input + 8);
+  }
+
+  /* Test long needles.  */
+  {
+    size_t m = 1024;
+    UNIT *haystack = (UNIT *) malloc ((2 * m + 1) * sizeof (UNIT));
+    UNIT *needle = (UNIT *) malloc ((m + 1) * sizeof (UNIT));
+    if (haystack != NULL && needle != NULL)
+      {
+        const UNIT *p;
+        haystack[0] = 'x';
+        U_SET (haystack + 1, ' ', m - 1);
+        U_SET (haystack + m, 'x', m);
+        haystack[2 * m] = '\0';
+        U_SET (needle, 'x', m);
+        needle[m] = '\0';
+        p = U_STRSTR (haystack, needle);
+        ASSERT (p);
+        ASSERT (p - haystack == m);
+      }
+    free (needle);
+    free (haystack);
+  }
 }
